From 89856e749bf14e63fed55a8f3436ea9a6f19667a Mon Sep 17 00:00:00 2001
From: Timothy Pearson
Date: Wed, 21 Dec 2011 14:23:49 -0600
Subject: Rename obsolete tq methods to standard names
---
superkaramba/examples/richtext/richtext.py | 4 ++--
superkaramba/examples/test_all.sh | 2 +-
superkaramba/examples/unicode/unicode.py | 6 +++---
superkaramba/src/karamba_python.cpp | 2 +-
superkaramba/src/themes_layout.ui | 2 +-
superkaramba/src/xmmssensor.cpp | 4 ++--
6 files changed, 10 insertions(+), 10 deletions(-)
(limited to 'superkaramba')
diff --git a/superkaramba/examples/richtext/richtext.py b/superkaramba/examples/richtext/richtext.py
index 11fe9d7..518aa65 100644
--- a/superkaramba/examples/richtext/richtext.py
+++ b/superkaramba/examples/richtext/richtext.py
@@ -1,6 +1,6 @@
#Unicode Example
-#For Symbol Tables look at www.tqunicode.org/charts/
+#For Symbol Tables look at www.unicode.org/charts/
hidden = 0
@@ -35,7 +35,7 @@ is used to encode the formatting commands.
Hyperlinks: Superkaramba Homepage
Links can also trigger actions in the script
Various different caracter styles
-Unicode: \u03B6 \u03B3 \u03BB \u03A3 \u03A9
+Unicode: \u03B6 \u03B3 \u03BB \u03A3 \u03A9
Simple Tables:
Header |
diff --git a/superkaramba/examples/test_all.sh b/superkaramba/examples/test_all.sh
index cdf192d..5e95063 100755
--- a/superkaramba/examples/test_all.sh
+++ b/superkaramba/examples/test_all.sh
@@ -10,7 +10,7 @@ themes=(
"richtext/richtext.theme"
"richtext/rtext.theme"
"globalMouse/eyes.theme"
- "tqunicode/tqunicode.theme"
+ "unicode/unicode.theme"
"mouseDrag/karmix/karmix.theme"
"input_api/input_api.theme"
"input_example/input_example.theme"
diff --git a/superkaramba/src/karamba_python.cpp b/superkaramba/src/karamba_python.cpp
index 99b901b..9f09f79 100644
--- a/superkaramba/src/karamba_python.cpp
+++ b/superkaramba/src/karamba_python.cpp
@@ -214,7 +214,7 @@ static PyMethodDef karamba_methods[] = {
{(char*)"showSystray", py_show_systray, METH_VARARGS, (char*)"Show the Systray"},
{(char*)"moveSystray", py_move_systray, METH_VARARGS, (char*)"Move the Systray"},
{(char*)"getCurrentWindowCount", py_get_current_window_count, METH_VARARGS, (char*)"Get current Window count"},
- {(char*)"updateSystrayLayout", py_update_systray_layout, METH_VARARGS, (char*)"Update Systray tqlayout"},
+ {(char*)"updateSystrayLayout", py_update_systray_layout, METH_VARARGS, (char*)"Update Systray layout"},
// Misc - misc_python.cpp
{(char*)"getThemePath", py_get_theme_path, METH_VARARGS, (char*)"Get the file path of the theme"},
diff --git a/superkaramba/src/themes_layout.ui b/superkaramba/src/themes_layout.ui
index 9fa108d..8b76e0b 100644
--- a/superkaramba/src/themes_layout.ui
+++ b/superkaramba/src/themes_layout.ui
@@ -27,7 +27,7 @@
- tqlayout2
+ layout2
diff --git a/superkaramba/src/xmmssensor.cpp b/superkaramba/src/xmmssensor.cpp
index d78d119..268700b 100644
--- a/superkaramba/src/xmmssensor.cpp
+++ b/superkaramba/src/xmmssensor.cpp
@@ -164,9 +164,9 @@ void XMMSSensor::update()
{
isPlaying = xmms->isPlaying(0);
pos = xmms->getPlaylistPos(0);
- qDebug("tqunicode start");
+ qDebug("unicode start");
title = codec->toUnicode( TQCString( xmms->getPlaylistTitle( 0, pos ) ) );
- qDebug("tqunicode end");
+ qDebug("unicode end");
if( title.isEmpty() )
title = "XMMS";
diff --git a/superkaramba/examples/unicode/unicode.py b/superkaramba/examples/unicode/unicode.py
index 1a15f83..13d1136 100644
--- a/superkaramba/examples/unicode/unicode.py
+++ b/superkaramba/examples/unicode/unicode.py
@@ -1,6 +1,6 @@
#Unicode Example
#For Symbol Tables look at www.tqunicode.org/charts/
#this import statement allows access to the karamba functions
@@ -31,8 +31,8 @@ def initWidget(widget):
\u0631\u0632\u0633\u0634\u0635\u0636\u0637\u0638\u0639\u063A\u0641\u0642\u0643\u0644\u0645\u0646
\u0647\u0648\u064A
-For a complete reference on tqunicode caracter codes look at:
-
www.tqunicode.org/charts/
+For a complete reference on unicode caracter codes look at:
+www.unicode.org/charts/
"""
karamba.resizeWidget(widget, 400, 400)
@@ -1,6 +1,6 @@
#Unicode Example
-#For Symbol Tables look at www.tqunicode.org/charts/
+#For Symbol Tables look at www.unicode.org/charts/
#this import statement allows access to the karamba functions
--
cgit v1.2.1